@@ -313,6 +313,10 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         # if options.get('extra_params', None):
         #     connstr += ';' + options['extra_params']
         print('connection String--> ', connstr)
+        import re
+        connstr = re.sub('attrs_before.*?};', '', connstr)
+        print('after connection String--> ', connstr)
+        print('atts_before Key: ',cstr_parts['attrs_before'])
         unicode_results = options.get('unicode_results', False)
         timeout = options.get('connection_timeout', 0)
         retries = options.get('connection_retries', 5)
@@ -326,6 +330,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
             try:
                 print('retry count: ', retry_count)
                 conn = Database.connect(connstr,
+                                        attrs_before=cstr_parts['attrs_before'],
                                         unicode_results=unicode_results,
                                         timeout=timeout)
             except Exception as e:
